aboutsummaryrefslogtreecommitdiff
path: root/bfd/cpu-maxq.c
diff options
context:
space:
mode:
authorNick Clifton <nickc@redhat.com>2005-01-10 16:33:51 +0000
committerNick Clifton <nickc@redhat.com>2005-01-10 16:33:51 +0000
commit5c4504f7c53c30ac373de048662365885bd51cb5 (patch)
tree3e971d44cb8e354482fd78db3f27e03ac6088c06 /bfd/cpu-maxq.c
parentb702665739598ec762119fda6dec4a09adc48fc0 (diff)
downloadgdb-5c4504f7c53c30ac373de048662365885bd51cb5.zip
gdb-5c4504f7c53c30ac373de048662365885bd51cb5.tar.gz
gdb-5c4504f7c53c30ac373de048662365885bd51cb5.tar.bz2
Add support for maxq10 and maxq20 machine values
Diffstat (limited to 'bfd/cpu-maxq.c')
-rw-r--r--bfd/cpu-maxq.c41
1 files changed, 29 insertions, 12 deletions
diff --git a/bfd/cpu-maxq.c b/bfd/cpu-maxq.c
index 9c36a16..bec43ea 100644
--- a/bfd/cpu-maxq.c
+++ b/bfd/cpu-maxq.c
@@ -1,5 +1,5 @@
/* BFD support for the MAXQ20/10 architecture.
- Copyright 2004 Free Software Foundation, Inc.
+ Copyright 2004, 2005 Free Software Foundation, Inc.
Written by Vineet Sharma(vineets@noida.hcltech.com)
Inderpreet Singh(inderpreetb@noida.hcltech.com)
@@ -25,18 +25,35 @@
#include "libbfd.h"
/* MAXQ Archtecture info. */
-const bfd_arch_info_type bfd_maxq_arch =
+static const bfd_arch_info_type bfd_maxq10_arch =
{
- 16, /* 16 bits in a word */
- 16, /* 16 bits in an address */
- 8, /* 16 bits in a byte */
- bfd_arch_maxq, /* enum bfd_archtecture arch */
- 0, /* only 1 machine */
- "maxq", /* arch_name */
- "maxq", /* printable name */
- 0, /* section align power */
- TRUE, /* the_default: if this is the machine */
- bfd_default_compatible, /* bfd_arch_info */
+ 16, /* 16 bits in a word. */
+ 16, /* 16 bits in an address. */
+ 8, /* 16 bits in a byte. */
+ bfd_arch_maxq, /* Architecture number. */
+ bfd_mach_maxq10, /* Machine number. */
+ "maxq", /* Architecture name. */
+ "maxq10", /* Machine name. */
+ 0, /* Section align power. */
+ FALSE, /* Not the default machine. */
+ bfd_default_compatible,
bfd_default_scan,
NULL
};
+
+
+const bfd_arch_info_type bfd_maxq_arch =
+{
+ 16, /* 16 bits in a word. */
+ 16, /* 16 bits in an address. */
+ 8, /* 16 bits in a byte. */
+ bfd_arch_maxq, /* Architecture number. */
+ bfd_mach_maxq20, /* Machine number. */
+ "maxq", /* Architecture name. */
+ "maxq20", /* Machine name. */
+ 0, /* Section align power. */
+ TRUE, /* This is the default machine. */
+ bfd_default_compatible,
+ bfd_default_scan,
+ & bfd_maxq10_arch
+};